@@ -69,8 +69,8 @@ mapvalues <- function(x, from, to, warn_missing = TRUE) {
   if (length(from) != length(to)) {
     stop("`from` and `to` vectors are not the same length.")
   }
-  if (!is.atomic(x)) {
-    stop("`x` must be an atomic vector.")
+  if (!is.atomic(x) && !is.null(x)) {
+    stop("`x` must be an atomic vector or NULL.")
   }
 
   if (is.factor(x)) {
