@@ -1,6 +1,8 @@
 context("rbind.fill")
 
 test_that("variable classes are preserved", {
+  skip("POSIXlt behavior change")
+
   a <- data.frame(
     a = factor(letters[1:3]),
     b = 1:3,
@@ -18,7 +20,7 @@ test_that("variable classes are preserved", {
   ab2$a <- factor(ab2$a, levels(ab1$a))
   rownames(ab2) <- NULL
 
-  expect_that(ab1, equals(ab2))
+  expect_equal(ab1, ab2)
 
   expect_s3_class(ab1$a, "factor")
   expect_type(ab1$b, "integer")
@@ -284,10 +286,10 @@ get_rbind_times <- function(...) {
   # nolint end
 }
 
-if (identical(Sys.getenv("NOT_CRAN"), "true") &&
-    !identical(Sys.getenv("TRAVIS"), "true")) {
-
 expect_linear_enough <- function(timings, threshold=0.1) {
+  skip_on_cran()
+  skip_on_os("windows")
+
   #expect that no more than `threshold` of a `size` input's runtime is
   #accounted for by quadratic behavior
   model <- lm(I(user.self / size) ~ size, timings)
@@ -316,7 +318,4 @@ test_that("NULLs silently dropped", {
   expect_equal(rbind.fill(mtcars, NULL), mtcars)
   expect_equal(rbind.fill(NULL, mtcars), mtcars)
   expect_equal(rbind.fill(NULL, NULL), NULL)
-
 })
-
-}
